# Advanced NLP and LLMs 2024

[![pypi-image]][pypi-url]
[![version-image]][release-url]
[![release-date-image]][release-url]
[![license-image]][license-url]
[![codecov][codecov-image]][codecov-url]
[![jupyter-book-image]][docs-url]

<!-- Links: -->
[codecov-image]: https://codecov.io/gh/entelecheia/deepnlp-2024/branch/main/graph/badge.svg?token=OMNrbNOBEj
[codecov-url]: https://codecov.io/gh/entelecheia/deepnlp-2024
[pypi-image]: https://img.shields.io/pypi/v/deepnlp-2024
[license-image]: https://img.shields.io/github/license/entelecheia/deepnlp-2024
[license-url]: https://github.com/entelecheia/deepnlp-2024/blob/main/LICENSE
[version-image]: https://img.shields.io/github/v/release/entelecheia/deepnlp-2024?sort=semver
[release-date-image]: https://img.shields.io/github/release-date/entelecheia/deepnlp-2024
[release-url]: https://github.com/entelecheia/deepnlp-2024/releases
[jupyter-book-image]: https://jupyterbook.org/en/stable/_images/badge.svg

[repo-url]: https://github.com/entelecheia/deepnlp-2024
[pypi-url]: https://pypi.org/project/deepnlp-2024
[docs-url]: https://deepnlp2024.jeju.ai
[changelog]: https://github.com/entelecheia/deepnlp-2024/blob/main/CHANGELOG.md
[contributing guidelines]: https://github.com/entelecheia/deepnlp-2024/blob/main/CONTRIBUTING.md
<!-- Links: -->

Advanced deep learning techniques for natural language processing using the NVIDIA NeMo framework and DGX H100 server

- Documentation: [https://deepnlp2024.jeju.ai][docs-url]
- GitHub: [https://github.com/entelecheia/deepnlp-2024][repo-url]
- PyPI: [https://pypi.org/project/deepnlp-2024][pypi-url]

This course focuses on advanced deep learning techniques for natural language processing using the NVIDIA NeMo framework and DGX H100 server. It emphasizes the training, optimization, and deployment of Large Language Models (LLMs), including practical application development. Students will gain hands-on LLM development experience through team projects.

## Changelog

See the [CHANGELOG] for more information.

## Contributing

Contributions are welcome! Please see the [contributing guidelines] for more information.

## License

This project is released under the [CC-BY-4.0 License][license-url].
